@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Default library paths 
-%  Last updated on August 22, 2016
+%  Last updated on October 17, 2016
 %
 %  This file is part of Logtalk <http://logtalk.org/>  
 %  Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -81,6 +81,7 @@ logtalk_library_path(home, HOME) :-
 logtalk_library_path(core, logtalk_home('core/')).
 
 % main directories in the Logtalk distribution
+logtalk_library_path(coding, logtalk_user('coding/')).
 logtalk_library_path(contributions, logtalk_user('contributions/')).
 logtalk_library_path(examples, logtalk_user('examples/')).
 logtalk_library_path(library, logtalk_user('library/')).
@@ -95,6 +96,7 @@ logtalk_library_path(xml_parser, contributions('xml_parser/')).
 
 % developer tools
 logtalk_library_path(assertions, tools('assertions/')).
+logtalk_library_path(dead_code_scanner, tools('dead_code_scanner/')).
 logtalk_library_path(debugger, tools('debugger/')).
 logtalk_library_path(diagrams, tools('diagrams/')).
 logtalk_library_path(doclet, tools('doclet/')).
@@ -164,9 +166,10 @@ logtalk_library_path(instvars, examples('instvars/')).
 logtalk_library_path(integration, threads('integration/')).
 logtalk_library_path(integration2d, threads('integration2d/')).
 logtalk_library_path(interactors, engines('interactors/')).
-logtalk_library_path(jpl, examples('jpl/')).
+logtalk_library_path(java, examples('java/')).
 logtalk_library_path(lambdas, examples('lambdas/')).
 logtalk_library_path(lambdas_compiled, examples('lambdas_compiled/')).
+logtalk_library_path(laptops, examples('laptops/')).
 logtalk_library_path(lazy, engines('lazy/')).
 logtalk_library_path(lo_planner, examples('lo/planner/')).
 logtalk_library_path(lo_travellers, examples('lo/travellers/')).
