@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on June 12, 2016
+##   Last updated on September 29, 2016
 ## 
 ##   This file is part of Logtalk <http://logtalk.org/>  
 ##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -27,7 +27,7 @@
 export LC_ALL=C
 
 print_version() {
-	echo "$(basename "$0") 0.16"
+	echo "$(basename "$0") 0.17"
 	exit 0
 }
 
@@ -77,16 +77,16 @@ format_xunit_goal="logtalk_load(lgtunit(xunit_report))"
 
 base="$PWD"
 results="$base/logtalk_tester_logs"
-backend=yap
-prolog='YAP'
-logtalk=yaplgt$extension
+backend=swipl
+prolog='SWI-Prolog'
+logtalk=swilgt$extension
 logtalk_call="$logtalk -g"
 mode='normal'
 format='default'
 format_goal=$format_default_goal
 # disable timeouts to maintain backward compatibility
 timeout=0
-prefix=""
+prefix="$HOME/"
 arguments=""
 
 run_tests() {
@@ -156,7 +156,7 @@ usage_help()
 	echo "     (possible values are default, tap, and xunit)"
 	echo "  -d directory to store the test logs (default is ./logtalk_tester_logs)"
 	echo "  -t timeout in seconds for running each test set (default is $timeout; i.e. disabled)"
-	echo "  -s supress path prefix (default is $prefix)"
+	echo "  -s supress path prefix (default is "$prefix")"
 	echo "  -- arguments to be passed to the integration script used to run the tests (no default)"
 	echo "  -h help"
 	echo
@@ -329,46 +329,46 @@ grep -a "Prolog version:" "$results"/tester_versions.txt | sed "s/Prolog/$prolog
 
 testsets=0
 output="$(find "$base" -name "tester.lgt" -or -name "tester.logtalk")"
-while read file; do
+while read file && [ "$file" != "" ]; do
 	((testsets++))
 	run_tests "$file"
 done <<< "$output"
 
 cd "$results"
-timeouts=$(grep -a 'LOGTALK_TIMEOUT' *.errors | wc -l | sed 's/ //g')
-crashes=$(grep -a 'LOGTALK_CRASH' *.errors | wc -l | sed 's/ //g')
+timeouts=$(grep -s -a 'LOGTALK_TIMEOUT' *.errors | wc -l | sed 's/ //g')
+crashes=$(grep -s -a 'LOGTALK_CRASH' *.errors | wc -l | sed 's/ //g')
 testsetruns=$(($testsets-$timeouts-$crashes))
-skipped=$(grep -a ': skipped' *.results | wc -l | sed 's/ //g')
-passed=$(grep -a ': success' *.results | wc -l | sed 's/ //g')
-failed=$(grep -a ': failure' *.results | wc -l | sed 's/ //g')
+skipped=$(grep -s -a ': skipped' *.results | wc -l | sed 's/ //g')
+passed=$(grep -s -a ': success' *.results | wc -l | sed 's/ //g')
+failed=$(grep -s -a ': failure' *.results | wc -l | sed 's/ //g')
 total=$(($skipped+$passed+$failed))
 
 echo "*******************************************************************************"
 echo "***** Compilation errors/warnings and failed unit tests"
 echo "***** (compilation errors/warnings might be expected depending on the test)"
 echo "*******************************************************************************"
-grep -a -A2 'syntax_error' *.results | sed 's/.results//' | tee errors.all
-grep -a -A2 'syntax_error' *.errors | sed 's/.errors//' | tee -a errors.all
-grep -a -h '!     ' *.errors | sed 's/.errors//' | tee -a errors.all
-grep -a -h '!     ' *.results | sed 's/.results//' | tee -a errors.all
-grep -a -h '*     ' *.errors | sed 's/.errors//' | tee -a errors.all
-grep -a -h '*     ' *.results | sed 's/.results//' | tee -a errors.all
+grep -s -a -A2 'syntax_error' *.results | sed 's/.results//' | tee errors.all
+grep -s -a -A2 'syntax_error' *.errors | sed 's/.errors//' | tee -a errors.all
+grep -s -a -h '!     ' *.errors | sed 's/.errors//' | tee -a errors.all
+grep -s -a -h '!     ' *.results | sed 's/.results//' | tee -a errors.all
+grep -s -a -h '*     ' *.errors | sed 's/.errors//' | tee -a errors.all
+grep -s -a -h '*     ' *.results | sed 's/.results//' | tee -a errors.all
 echo "*******************************************************************************"
 echo "***** Timeouts"
 echo "*******************************************************************************"
-grep -a 'LOGTALK_TIMEOUT' *.errors | sed 's/LOGTALK_TIMEOUT//' | sed 's/.errors://' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a 'LOGTALK_TIMEOUT' *.errors | sed 's/LOGTALK_TIMEOUT//' | sed 's/.errors://' | sed 's|__|/|g' | sed "s|^$prefix||"
 echo "*******************************************************************************"
 echo "***** Crashes"
 echo "*******************************************************************************"
-grep -a 'LOGTALK_CRASH' *.errors | sed 's/LOGTALK_CRASH//' | sed 's/.errors://' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a 'LOGTALK_CRASH' *.errors | sed 's/LOGTALK_CRASH//' | sed 's/.errors://' | sed 's|__|/|g' | sed "s|^$prefix||"
 echo "*******************************************************************************"
 echo "***** Skipped tests"
 echo "*******************************************************************************"
-grep -a ': skipped' *.results | sed 's/: skipped//' | sed 's/.results:% / - /' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a ': skipped' *.results | sed 's/: skipped//' | sed 's/.results:% / - /' | sed 's|__|/|g' | sed "s|^$prefix||"
 echo "*******************************************************************************"
 echo "***** Failed tests"
 echo "*******************************************************************************"
-grep -a ': failure' *.results | sed 's/: failure//' | sed 's/.results:!     / - /' | sed 's|__|/|g' | sed "s|^$prefix||"
+grep -s -a ': failure' *.results | sed 's/: failure//' | sed 's/.results:!     / - /' | sed 's|__|/|g' | sed "s|^$prefix||"
 echo "*******************************************************************************"
 echo "***** $testsets test sets: $testsetruns completed, $timeouts timeouts, $crashes crashes"
 echo "***** $total tests: $skipped skipped, $passed passed, $failed failed"
