@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Logtalk script for updating the HTML library and tools documentation
-##   Last updated on March 12, 2016
+##   Last updated on October 13, 2016
 ## 
 ##   This file is part of Logtalk <http://logtalk.org/>  
 ##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -49,7 +49,7 @@ goal="set_logtalk_flag(source_data,on),logtalk_load([library(all_loader),tools(l
 
 
 print_version() {
-	echo "`basename $0` 0.6"
+	echo "`basename $0` 0.7"
 	exit 0
 }
 
@@ -66,7 +66,7 @@ usage_help()
 	echo
 	echo "Optional arguments:"
 	echo "  -p back-end Prolog compiler (default is $backend)"
-	echo "     (possible values are b, cx, eclipse, gnu, lean, qp, sicstus, swi, xsb, xsbmt, and yap)"
+	echo "     (possible values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, xsb, xsbmt, and yap)"
 	echo "  -v print version of `basename $0`"
 	echo "  -h help"
 	echo
@@ -97,6 +97,9 @@ elif [ "$p_arg" == "eclipse" ] ; then
 elif [ "$p_arg" == "gnu" ] ; then
 	prolog='GNU Prolog'
 	logtalk="gplgt$extension --query-goal"
+elif [ "$p_arg" == "ji" ] ; then
+	prolog='JIProlog'
+	logtalk="jiplgt$extension -n -g"
 elif [ "$p_arg" == "lean" ] ; then
 	prolog='Lean Prolog'
 	logtalk="lplgt$extension"
@@ -132,5 +135,7 @@ $logtalk "$goal"
 cd "$cwd/../docs"
 lgt2html
 rm *.xml
+rm *.dtd
+rm *.xsd
 
 exit 0
