@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////
 //
 //   XML documenting files to plain text conversion script 
-//   Last updated on February 17, 2016
+//   Last updated on July 5, 2016
 //
 //   This file is part of Logtalk <http://logtalk.org/>  
 //   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
@@ -129,7 +129,7 @@ for (files.moveFirst(); !files.atEnd(); files.moveNext()) {
 	if (FSObject.GetExtensionName(file) == "xml") {
 		WScript.Echo("  converting " + file);
 		var txt_file = directory + "\\" + FSObject.GetBaseName(file) + ".txt";
-		if (file == "directory_index.xml" || file == "entity_index.xml" || file == "predicate_index.xml") {
+		if (file == "library_index.xml" || file == "directory_index.xml" || file == "entity_index.xml" || file == "predicate_index.xml") {
 			xslt = index_xslt;
 		} else {
 			xslt = entity_xslt;
